@@ -1,6 +1,7 @@
 from typing import Type, Union, Literal, Optional, Dict, List, Tuple, Set, Annotated, Any
-from mindor.core.utils.renderer import VariableRenderer
+from mindor.core.utils.renderers import VariableRenderer, ImageValueRenderer
 from mindor.core.gateway import find_gateway_by_port
+from PIL import Image as PILImage
 
 class ComponentActionContext:
     def __init__(self, run_id: str, input: Dict[str, Any]):
@@ -13,23 +14,35 @@ class ComponentActionContext:
     def register_source(self, key: str, source: Any) -> None:
         self.sources[key] = source
 
-    async def render_variable(self, data: Dict[str, Any], ignore_files: bool = False) -> Any:
-        return await self.renderer.render(data, ignore_files)
+    async def render_variable(self, value: Any, ignore_files: bool = False) -> Any:
+        return await self.renderer.render(value, ignore_files)
+
+    async def render_image(self, value: Any) -> Optional[PILImage.Image]:
+        return await ImageValueRenderer().render(await self.render_variable(value))
+
+    def contains_variable_reference(self, key: str, value: Any) -> bool:
+        return self.renderer.contains_reference(key, value)
 
     async def _resolve_source(self, key: str, index: Optional[int]) -> Any:
         if key in self.sources:
             return self.sources[key][index] if index is not None else self.sources[key]
+
         if key == "input":
             return self.input
+
         if key == "context":
             return self.context
+
         if key.startswith("gateway:"):
             return self._resolve_gateway(key)
+
         raise KeyError(f"Unknown source: {key}")
 
     def _resolve_gateway(self, key: str) -> Any:
         _, port = key.split(":")
         gateway = find_gateway_by_port(int(port)) if port else None
+
         if gateway:
-            return gateway.get_context()
+            return gateway.get_context(int(port))
+
         return None
