@@ -3,5 +3,9 @@ from .http_client import *
 from .mcp_server import *
 from .mcp_client import *
 from .model import *
+from .datasets import *
+from .vector_store import *
 from .workflow import *
 from .shell import *
+from .text_splitter import *
+from .image_processor import *
