@@ -9,10 +9,10 @@ async def terminate_services(config: ComposeConfig, verbose: bool):
     await ComposeManager(config, daemon=False).terminate_services(verbose)
 
 async def start_services(config: ComposeConfig, verbose: bool):
-    await ComposeManager(config, daemon=False).start_services(verbose)
+    await ComposeManager(config, daemon=True).start_services(verbose)
 
 async def stop_services(config: ComposeConfig, verbose: bool):
     await ComposeManager(config, daemon=False).stop_services(verbose)
 
-async def run_workflow(config: ComposeConfig, workflow_id: Optional[str], input: Dict[str, Any], verbose: bool) -> TaskState:
-    return await ComposeManager(config, daemon=False).run_workflow(workflow_id, input, verbose)
+async def run_workflow(config: ComposeConfig, workflow_id: str, input: Dict[str, Any], output_path: Optional[str], verbose: bool) -> TaskState:
+    return await ComposeManager(config, daemon=False).run_workflow(workflow_id, input, output_path, verbose)
