@@ -1,6 +1,6 @@
 from typing import Type, Union, Literal, Optional, Dict, List, Tuple, Set, Annotated, Any
 from mindor.dsl.schema.compose import ComposeConfig
-from mindor.core.controller import ControllerService, TaskState, create_controller
+from mindor.core.controller import ControllerService, TaskState, TaskStatus, create_controller
 
 class ComposeManager:
     def __init__(self, config: ComposeConfig, daemon: bool):
@@ -16,19 +16,28 @@ class ComposeManager:
         )
 
     async def launch_services(self, detach: bool, verbose: bool):
-        await self.controller.launch(detach, verbose)
+        await self.controller.launch_services(detach, verbose)
 
     async def terminate_services(self, verbose: bool):
-        await self.controller.terminate(verbose)
+        await self.controller.terminate_services(verbose)
 
     async def start_services(self, verbose: bool):
-        await self.controller.start()
+        await self.controller.start_services(verbose)
 
     async def stop_services(self, verbose: bool):
-        await self.controller.stop()
+        await self.controller.stop_services(verbose)
 
-    async def run_workflow(self, workflow_id: Optional[str], input: Dict[str, Any], verbose: bool) -> TaskState:
+    async def run_workflow(self, workflow_id: str, input: Dict[str, Any], output_path: Optional[str], verbose: bool) -> TaskState:
         if not self.controller.started:
             await self.controller.start()
 
-        return await self.controller.run_workflow(workflow_id, input)
+        state = await self.controller.run_workflow(workflow_id, input)
+
+        if output_path and state.status == TaskStatus.COMPLETED:
+            await self._save_output(state.output, output_path)
+            state.output = None
+
+        return state
+
+    async def _save_output(self, output: Any, path: str) -> None:
+        pass
