@@ -5,12 +5,12 @@ from mindor.dsl.schema.listener import ListenerConfig
 from mindor.dsl.schema.gateway import GatewayConfig
 from mindor.dsl.schema.workflow import WorkflowConfig
 from mindor.dsl.schema.logger import LoggerConfig
-from .base import ControllerService, ControllerRegistry
+from .base import ControllerService, ControllerRegistry, TaskStatus
 
 def create_controller(
     config: ControllerConfig,
-    workflows: Dict[str, WorkflowConfig],
-    components: Dict[str, ComponentConfig],
+    workflows: List[WorkflowConfig],
+    components: List[ComponentConfig],
     listeners: List[ListenerConfig],
     gateways: List[GatewayConfig],
     loggers: List[LoggerConfig],
