@@ -9,7 +9,7 @@ class HttpControllerClient(ControllerClient):
     def __init__(self, config: ControllerConfig):
         super().__init__(config)
 
-        self.client: HttpClient = HttpClient(self._resolve_controller_url())
+        self.client: HttpClient = HttpClient(self._resolve_controller_url(), timeout=3600)
 
     async def run_workflow(self, workflow_id: Optional[str], input: Any, workflow: WorkflowSchema) -> Any:
         body = {
@@ -18,23 +18,24 @@ class HttpControllerClient(ControllerClient):
             "wait_for_completion": True,
             "output_only": True
         }
-        headers = {
-            "Content-Type": "application/json"
-        }
 
         if self._contains_upload_file(input):
             body = { key: value for key, value in self._flatten_for_multipart(body) }
             headers = {
                 "Content-Type": "multipart/form-data"
             }
+        else:
+            headers = {
+                "Content-Type": "application/json"
+            }
 
-        return await self.client.request("/workflows", "POST", None, body, headers)
+        return await self.client.request("/workflows/runs", "POST", None, body, headers)
 
     async def close(self) -> None:
         await self.client.close()
 
     def _resolve_controller_url(self) -> str:
-        return f"http://localhost:{self.config.port}{self.config.base_path or ''}"
+        return f"http://localhost:{self.config.port}" + (self.config.base_path or "")
     
     def _flatten_for_multipart(self, data: Dict[str, Any], key: str = "") -> List[Tuple[str, Any]]:
         flattened = []
@@ -55,7 +56,8 @@ class HttpControllerClient(ControllerClient):
                         flattened.append((list_key, item))
                 continue
 
-            flattened.append((full_key, value))
+            if value is not None:
+                flattened.append((full_key, value))
 
         return flattened
 
