@@ -6,8 +6,12 @@ from mindor.core.utils.streaming import save_stream_to_temporary_file
 from mindor.core.utils.http_request import create_upload_file
 from mindor.core.utils.http_client import create_stream_with_url
 from mindor.core.utils.image import load_image_from_stream
+from mindor.core.utils.resolvers import FieldResolver
+from PIL import Image as PILImage
 import gradio as gr
-import json
+import json, re
+
+_variable_name_regex = re.compile(r"^([^[]+)(?:\[(\w+)\])?$")
 
 class ComponentGroup:
     def __init__(self, group: gr.Component, components: List[gr.Component]):
@@ -15,13 +19,16 @@ class ComponentGroup:
         self.components: List[gr.Component] = components
 
 class GradioWebUIBuilder:
-    def build(self, schema: Dict[str, WorkflowSchema], runner: Callable[[Optional[str], Any], Awaitable[Any]]) -> gr.Blocks:
-        with gr.Blocks() as blocks:
-            for workflow_id, workflow in schema.items():
-                async def _run_workflow(input: Any, workflow_id=workflow_id) -> Any:
-                    return await runner(workflow_id, input)
+    def __init__(self):
+        self.field_resolver: FieldResolver = FieldResolver()
 
-                if len(schema) > 1:
+    def build(self, workflow_schemas: Dict[str, WorkflowSchema], workflow_runner: Callable[[Optional[str], Any], Awaitable[Any]]) -> gr.Blocks:
+        with gr.Blocks() as blocks:
+            for workflow_id, workflow in workflow_schemas.items():
+                async def _run_workflow(input: Any, workflow_id=workflow_id) -> Any:
+                    return await workflow_runner(workflow_id, input)
+
+                if len(workflow_schemas) > 1:
                     with gr.Tab(label=workflow.name or workflow_id):
                         self._build_workflow_section(workflow, _run_workflow)
                 else:
@@ -32,7 +39,7 @@ class GradioWebUIBuilder:
     def _build_workflow_section(self, workflow: WorkflowSchema, runner: Callable[[Any], Awaitable[Any]]) -> gr.Column:
         with gr.Column() as section:
             gr.Markdown(f"## **{workflow.title or 'Untitled Workflow'}**")
- 
+
             if workflow.description:
                 gr.Markdown(f"📝 {workflow.description}")
 
@@ -44,14 +51,25 @@ class GradioWebUIBuilder:
             output_components = [ self._build_output_component(variable) for variable in workflow.output ]
 
             if not output_components:
-                output_components = [ gr.Textbox(label="", lines=8, interactive=False, show_copy_button=True) ]
+                output_components = [ gr.Textbox(label="", lines=10, interactive=False, show_copy_button=True) ]
 
             async def _run_workflow(*args):
                 input = await self._build_input_value(args, workflow.input)
                 output = await runner(input)
-                if workflow.output:
-                    output = await self._flatten_output_value(output, workflow.output)
-                return output[0] if len(output) == 1 else output
+
+                if len(workflow.output) == 1 and self._is_streaming_variable(workflow.output[0]):
+                    buffer = "" if workflow.output[0].type == WorkflowVariableType.TEXT else []
+                    async for chunk in output:
+                        chunk = await self._flatten_output_value(chunk, [ workflow.output[0]])
+                        if workflow.output[0].type == WorkflowVariableType.TEXT:
+                            buffer += chunk[0] or ""
+                        else:
+                            buffer.append(chunk[0])
+                        yield buffer
+                else:
+                    if workflow.output:
+                        output = await self._flatten_output_value(output, workflow.output)
+                    yield output[0] if len(output) == 1 else output
 
             run_button.click(
                 fn=_run_workflow,
@@ -61,20 +79,34 @@ class GradioWebUIBuilder:
 
         return section
 
+    def _is_streaming_variable(self, variable: Union[WorkflowVariableConfig, WorkflowVariableGroupConfig]) -> bool:
+        if isinstance(variable, WorkflowVariableConfig):
+            return variable.format in [ WorkflowVariableFormat.SSE_JSON, WorkflowVariableFormat.SSE_TEXT ]
+        return False
+
     def _build_input_component(self, variable: WorkflowVariableConfig) -> gr.Component:
-        label = (variable.name or "") + (" *" if variable.required else "") + (f" (default: {variable.default})" if variable.default else "")
+        label = (variable.name or "") + (" *" if variable.required else "") + (f" (default: {variable.default})" if variable.default is not None else "")
         info = variable.get_annotation_value("description") or ""
         default = variable.default
 
         if variable.type == WorkflowVariableType.STRING or variable.format in [ WorkflowVariableFormat.BASE64, WorkflowVariableFormat.URL ]:
             return gr.Textbox(label=label, value="", info=info)
+        
+        if variable.type == WorkflowVariableType.TEXT:
+            return gr.Textbox(label=label, value="", lines=5, max_lines=15, info=info)
 
-        if variable.type in [ WorkflowVariableType.INTEGER, WorkflowVariableType.NUMBER ]:
+        if variable.type == WorkflowVariableType.INTEGER:
+            return gr.Textbox(label=label, value="", info=info)
+
+        if variable.type == WorkflowVariableType.NUMBER:
             return gr.Number(label=label, value="", info=info)
 
         if variable.type == WorkflowVariableType.BOOLEAN:
             return gr.Checkbox(label=label, value=default or False, info=info)
         
+        if variable.type == WorkflowVariableType.LIST:
+            return gr.Textbox(label=label, value=default or "", info=info)
+
         if variable.type == WorkflowVariableType.IMAGE:
             return gr.Image(label=label, type="filepath")
 
@@ -108,6 +140,12 @@ class GradioWebUIBuilder:
                 value = await self._save_value_to_temporary_file(value, subtype, format)
             return create_upload_file(value, type.value, subtype) if value is not None else None
 
+        if type == WorkflowVariableType.INTEGER:
+            return int(value) if value != "" else None
+
+        if type == WorkflowVariableType.LIST:
+            return str(value).split(",")
+
         return value if value != "" else None
 
     def _build_output_component(self, variable: Union[WorkflowVariableConfig, WorkflowVariableGroupConfig]) -> Union[gr.Component, List[ComponentGroup]]:
@@ -126,6 +164,12 @@ class GradioWebUIBuilder:
         if variable.type in [ WorkflowVariableType.STRING, WorkflowVariableType.BASE64 ]:
             return gr.Textbox(label=label, interactive=False, show_copy_button=True, info=info)
 
+        if variable.type in [ WorkflowVariableType.NUMBER, WorkflowVariableType.INTEGER ]:
+            return gr.Textbox(label=label, interactive=False, show_copy_button=True, info=info)
+
+        if variable.type == WorkflowVariableType.TEXT:
+            return gr.Textbox(label=label, lines=5, max_lines=30, interactive=False, show_copy_button=True, info=info)
+
         if variable.type == WorkflowVariableType.MARKDOWN:
             return gr.Markdown(label=label)
         
@@ -157,17 +201,39 @@ class GradioWebUIBuilder:
         flattened = []
         for variable in variables:
             if isinstance(variable, WorkflowVariableGroupConfig):
-                group = output[variable.name] if variable.name in output else None if variable.name else output
+                group = self._resolve_variable_output(output, variable)
                 for value in group or ():
                     flattened.extend(await self._flatten_output_value(value, variable.variables))
             else:
-                value = output[variable.name] if variable.name in output else None if variable.name else output
+                value = self._resolve_variable_output(output, variable)
                 flattened.append(await self._convert_output_value(value, variable.type, variable.subtype, variable.format, variable.internal))
         return flattened
 
+    def _resolve_variable_output(self, output: Any, variable: Union[WorkflowVariableConfig, WorkflowVariableGroupConfig]) -> Any:
+        if isinstance(output, dict) and variable.name:
+            m = re.match(_variable_name_regex, variable.name)
+            if not m:
+                return None
+
+            name, index = m.group(1, 2)
+            if name not in output:
+                return None
+
+            if isinstance(output[name], list) and index:
+                if int(index) < len(output[name]):
+                    return output[name][int(index)]
+                return None
+
+            return output[name]
+
+        return None if variable.name else output
+
     async def _convert_output_value(self, value: Any, type: WorkflowVariableType, subtype: Optional[str], format: Optional[WorkflowVariableFormat], internal: bool) -> Any:
-        if type == WorkflowVariableType.STRING:
-            return json.dumps(value) if isinstance(value, (dict, list)) else str(value) if value is not None else None
+        if format == WorkflowVariableFormat.SSE_JSON:
+            return self._resolve_json_field_from_bytes(value, subtype, format)
+
+        if type in [ WorkflowVariableType.STRING, WorkflowVariableType.TEXT ]:
+            return self._convert_value_to_string(value, subtype, format)
 
         if type == WorkflowVariableType.IMAGE:
             return await self._load_image_from_value(value, subtype, format)
@@ -177,7 +243,25 @@ class GradioWebUIBuilder:
 
         return value
 
-    async def _load_image_from_value(self, value: Any, subtype: Optional[str], format: Optional[WorkflowVariableFormat]) -> Optional[str]:
+    def _convert_value_to_string(self, value: Any, subtype: Optional[str], format: Optional[WorkflowVariableFormat]) -> Optional[str]:
+        if isinstance(value, (dict, list)):
+            return json.dumps(value)
+        
+        if isinstance(value, bytes):
+            return value.decode("utf-8", errors="replace")
+
+        if value is not None:
+            return str(value)
+
+        return None
+    
+    def _resolve_json_field_from_bytes(self, value: Any, subtype: Optional[str], format: Optional[WorkflowVariableFormat]) -> Optional[Any]:
+        try:
+            return self.field_resolver.resolve(json.loads(value), subtype)
+        except Exception:
+            return None
+
+    async def _load_image_from_value(self, value: Any, subtype: Optional[str], format: Optional[WorkflowVariableFormat]) -> Optional[PILImage.Image]:
         if format == WorkflowVariableFormat.BASE64 and isinstance(value, str):
             return await load_image_from_stream(Base64StreamResource(value), subtype)
 
