@@ -1,7 +1,7 @@
 from typing import Type, Union, Literal, Optional, Dict, List, Tuple, Set, Annotated, Callable, Any
 from abc import ABC, abstractmethod
 from mindor.dsl.schema.logger import LoggerConfig, LoggerType, LoggingLevel
-from mindor.core.services import AsyncService
+from mindor.core.foundation import AsyncService
 
 class LoggerService(AsyncService):
     def __init__(self, id: str, config: LoggerConfig, daemon: bool):
