@@ -1,16 +1,16 @@
 from typing import Type, Union, Literal, Optional, Dict, List, Tuple, Set, Annotated, Callable, Any
 from mindor.dsl.schema.job import DelayJobConfig, DelayJobMode
-from mindor.dsl.schema.component import ComponentConfig
+from mindor.core.component import ComponentGlobalConfigs
 from mindor.core.utils.time import parse_duration, parse_datetime, TimeTracker
 from mindor.core.logger import logging
 from ..base import Job, JobType, WorkflowContext, RoutingTarget, register_job
-from datetime import datetime, timedelta
+from datetime import datetime
 import asyncio
 
 @register_job(JobType.DELAY)
 class DelayJob(Job):
-    def __init__(self, id: str, config: DelayJobConfig, components: Dict[str, ComponentConfig]):
-        super().__init__(id, config, components)
+    def __init__(self, id: str, config: DelayJobConfig, global_configs: ComponentGlobalConfigs):
+        super().__init__(id, config, global_configs)
 
     async def run(self, context: WorkflowContext) -> Any:
         output = await self._delay(self.config.mode, context)
