@@ -1,4 +1,5 @@
 from typing import Type, Union, Literal, Optional, Dict, List, Tuple, Set, Annotated, Callable, Any
+from types import GeneratorType
 from mindor.dsl.schema.workflow import WorkflowConfig, JobConfig
 from mindor.dsl.schema.component import ComponentConfig
 from mindor.core.component import ComponentGlobalConfigs
@@ -21,23 +22,23 @@ class JobGraphValidator:
         for job_id, job in self.jobs.items():
             for dependency_id in job.depends_on:
                 if dependency_id == job_id:
-                    raise  ValueError(f"Job '{job_id}' cannot depend on itself.")
+                    raise  ValueError(f"Job '{job_id}' cannot depend on itself")
                 
                 if dependency_id not in self.jobs:
-                    raise ValueError(f"Job '{job_id}' references a non-existent job '{dependency_id}' in its depends_on list.")
+                    raise ValueError(f"Job '{job_id}' references a non-existent job '{dependency_id}' in its depends_on list")
 
     def _validate_has_entry_jobs(self) -> None:
         entry_job_ids = [ job_id for job_id, job in self.jobs.items() if not job.depends_on ]
 
         if not entry_job_ids:
-            raise ValueError("At least one job without any depends_on is required.")
+            raise ValueError("At least one job without any depends_on is required")
 
     def _validate_has_no_cycles(self) -> None:
         visiting, visited = set(), set()
 
         def _assert_no_cycle(job_id: str):
             if job_id in visiting:
-                raise ValueError(f"Job '{job_id}' is part of a dependency cycle.")
+                raise ValueError(f"Job '{job_id}' is part of a dependency cycle")
             
             if job_id not in visited:
                 visiting.add(job_id)
@@ -53,32 +54,28 @@ class JobGraphValidator:
                 _assert_no_cycle(job_id)
 
 class WorkflowResolver:
-    def __init__(self, workflows: Dict[str, WorkflowConfig]):
-        self.workflows: Dict[str, WorkflowConfig] = workflows
+    def __init__(self, workflows: List[WorkflowConfig]):
+        self.workflows: List[WorkflowConfig] = workflows
 
-    def resolve(self, workflow_id: Optional[str]) -> Tuple[str, WorkflowConfig]:
-        workflow_id = workflow_id or self._find_default_id(self.workflows)
+    def resolve(self, workflow_id: str, raise_on_error: bool = True) -> Union[Tuple[str, WorkflowConfig], Tuple[None, None]]:
+        if workflow_id == "__default__":
+            workflow = self.workflows[0] if len(self.workflows) == 1 else None
+            workflow = workflow or next((workflow for workflow in self.workflows if workflow.default), None)
+        else:
+            workflow = next((workflow for workflow in self.workflows if workflow.id == workflow_id), None)
 
-        if not workflow_id in self.workflows:
-            raise ValueError(f"Workflow not found: {workflow_id}")
+        if workflow is None:
+            if raise_on_error:
+                raise ValueError(f"Workflow not found: {workflow_id}")
+            else:
+                return (None, None)
 
-        return workflow_id, self.workflows[workflow_id]
-
-    def _find_default_id(self, workflows: Dict[str, WorkflowConfig]) -> str:
-        default_ids = [ workflow_id for workflow_id, workflow in workflows.items() if workflow.default ]
-
-        if len(default_ids) > 1:
-            raise ValueError("Multiple workflows have default: true")
-
-        if not default_ids and "__default__" not in workflows:
-            raise ValueError("No default workflow defined.")
-
-        return default_ids[0] if default_ids else "__default__"
+        return workflow.id, workflow
 
 class WorkflowRunner:
-    def __init__(self, id: str, jobs: Dict[str, JobConfig], global_configs: ComponentGlobalConfigs):
+    def __init__(self, id: str, jobs: List[JobConfig], global_configs: ComponentGlobalConfigs):
         self.id: str = id
-        self.jobs: Dict[str, JobConfig] = jobs
+        self.jobs: Dict[str, JobConfig] = { job.id: job for job in jobs }
         self.global_configs: ComponentGlobalConfigs = global_configs
 
     async def run(self, context: WorkflowContext) -> Any:
@@ -142,7 +139,8 @@ class WorkflowRunner:
                 del pending_jobs[completed_job_id]
                 del scheduled_job_tasks[completed_job_id]
 
-        logging.info("[task-%s] Workflow '%s' completed in %.2f seconds.", context.task_id, self.id, workflow_time_tracker.elapsed())
+        if not isinstance(output, GeneratorType):
+            logging.info("[task-%s] Workflow '%s' completed in %.2f seconds.", context.task_id, self.id, workflow_time_tracker.elapsed())
 
         return output
 
