@@ -9,5 +9,7 @@ ActionConfig = Union[
     McpClientActionConfig,
     ModelActionConfig,
     WorkflowActionConfig,
-    ShellActionConfig
+    ShellActionConfig,
+    TextSplitterActionConfig,
+    ImageProcessorActionConfig
 ]
