@@ -3,9 +3,5 @@ from enum import Enum
 from pydantic import BaseModel, Field
 from ...common import CommonActionConfig
 
-class ModelTaskMode(str, Enum):
-    INFERENCE = "inference"
-    TRAINING  = "training"
-
 class CommonModelActionConfig(CommonActionConfig):
-    mode: ModelTaskMode = Field(default=ModelTaskMode.INFERENCE, description="")
+    streaming: Union[bool, str] = Field(default=None, description="Whether to enable streaming responses for inference.")
