@@ -4,8 +4,9 @@ from .impl import *
 
 ModelActionConfig = Union[
     TextGenerationModelActionConfig,
-    SummarizationModelActionConfig,
-    TranslationModelActionConfig,
+    ChatCompletionModelActionConfig,
     TextClassificationModelActionConfig,
     TextEmbeddingModelActionConfig,
+    ImageToTextModelActionConfig,
+    ImageUpscaleModelActionConfig,
 ]
