@@ -9,8 +9,12 @@ ComponentConfig = Annotated[
         McpServerComponentConfig,
         McpClientComponentConfig,
         ModelComponentConfig,
+        DatasetsComponentConfig,
+        VectorStoreComponentConfig,
         WorkflowComponentConfig,
-        ShellComponentConfig
+        ShellComponentConfig,
+        TextSplitterComponentConfig,
+        ImageProcessorComponentConfig
     ],
     Field(discriminator="type")
 ]
