@@ -5,10 +5,13 @@ from .impl import *
 ModelComponentConfig = Annotated[
     Union[ 
         TextGenerationModelComponentConfig,
-        SummarizationModelComponentConfig,
-        TranslationModelComponentConfig,
+        ChatCompletionModelComponentConfig,
         TextClassificationModelComponentConfig,
         TextEmbeddingModelComponentConfig,
+        ImageToTextModelComponentConfig,
+        ImageGenerationModelComponentConfig,
+        ImageUpscaleModelComponentConfig,
+        FaceEmbeddingeModelComponentConfig
     ],
     Field(discriminator="task")
 ]
