@@ -11,20 +11,20 @@ from .logger import LoggerConfig
 
 class ComposeConfig(BaseModel):
     controller: ControllerConfig
-    components: Dict[str, ComponentConfig] = Field(default_factory=dict, description="")
-    listeners: List[ListenerConfig] = Field(default_factory=list, description="")
-    gateways: List[GatewayConfig] = Field(default_factory=list, description="")
-    workflows: Dict[str, WorkflowConfig] = Field(default_factory=dict, description="")
-    loggers: List[LoggerConfig] = Field(default_factory=list, description="")
+    components: List[ComponentConfig] = Field(default_factory=list, description="List of reusable components that define API calls, model tasks, or other operations")
+    listeners: List[ListenerConfig] = Field(default_factory=list, description="List of listeners for handling asynchronous responses from external services.")
+    gateways: List[GatewayConfig] = Field(default_factory=list, description="List of gateway services for tunneling local endpoints to public.")
+    workflows: List[WorkflowConfig] = Field(default_factory=list, description="List of workflows that define sequences of jobs and their execution flow.")
+    loggers: List[LoggerConfig] = Field(default_factory=list, description="List of logger configurations for capturing and storing execution logs.")
 
     @model_validator(mode="before")
     def inflate_single_component(cls, values: Dict[str, Any]):
         if "components" not in values:
             component_values = values.pop("component", None)
             if component_values:
-                values["components"] = { "__default__": component_values }
+                values["components"] = [ component_values ]
         return values
-    
+
     @model_validator(mode="before")
     def inflate_single_listener(cls, values: Dict[str, Any]):
         if "listeners" not in values:
@@ -45,8 +45,8 @@ class ComposeConfig(BaseModel):
     def inflate_single_workflow(cls, values: Dict[str, Any]):
         if "workflows" not in values:
             workflow_values = values.pop("workflow", None)
-            if workflow_values: 
-                values["workflows"] = { "__default__": workflow_values }
+            if workflow_values:
+                values["workflows"] = [ workflow_values ]
         return values
 
     @model_validator(mode="before")
