@@ -4,6 +4,5 @@ from mindor.dsl.schema.runtime import RuntimeType
 from .types import GatewayType
 
 class CommonGatewayConfig(BaseModel):
-    type: GatewayType = Field(..., description="")
-    runtime: RuntimeType = Field(default=RuntimeType.NATIVE)
-    port: Optional[int] = Field(default=8090)
+    type: GatewayType = Field(..., description="Type of gateway service.")
+    runtime: RuntimeType = Field(default=RuntimeType.NATIVE, description="Runtime environment for executing the gateway service.")
