@@ -15,12 +15,12 @@ class CommonDelayJobConfig(OutputJobConfig):
 
 class TimeIntervalDelayJobConfig(CommonDelayJobConfig):
     mode: Literal[DelayJobMode.TIME_INTERVAL]
-    duration: Union[str, float, int] = Field(..., description="Time to wait before continuing.")
+    duration: Union[float, int, str] = Field(..., description="Time to wait before continuing.")
 
 class SpecificTimeDelayJobConfig(CommonDelayJobConfig):
     mode: Literal[DelayJobMode.SPECIFIC_TIME]
     time: Union[datetime, str] = Field(..., description="Specific date and time to wait until.")
-    timezone: Optional[str] = Field(default=None, description="")
+    timezone: Optional[str] = Field(default=None, description="Timezone identifier used to interpret the 'time' field.")
 
 DelayJobConfig = Annotated[
     Union[ 
