@@ -7,7 +7,9 @@ JobConfig = Annotated[
         ActionJobConfig,
         DelayJobConfig,
         IfJobConfig,
-        SwitchJobConfig
+        SwitchJobConfig,
+        RandomRouterJobConfig,
+        FilterJobConfig
     ],
     Field(discriminator="type")
 ]
