@@ -3,7 +3,7 @@ from enum import Enum
 from pydantic import BaseModel, Field
 from pydantic import model_validator, field_validator
 from mindor.dsl.utils.annotation import get_model_union_keys
-from .job import JobConfig, JobType
+from .job import JobConfig, JobType, DelayJobMode
 
 class WorkflowVariableType(str, Enum):
     # Primitive data types
@@ -12,6 +12,7 @@ class WorkflowVariableType(str, Enum):
     INTEGER  = "integer"
     NUMBER   = "number"
     BOOLEAN  = "boolean"
+    LIST     = "list"
     JSON     = "json"
     OBJECTS  = "object[]"
     # Encoded data
@@ -26,10 +27,12 @@ class WorkflowVariableType(str, Enum):
     SELECT   = "select"
 
 class WorkflowVariableFormat(str, Enum):
-    BASE64 = "base64"
-    URL    = "url"
-    PATH   = "path"
-    STREAM = "stream"
+    BASE64   = "base64"
+    URL      = "url"
+    PATH     = "path"
+    STREAM   = "stream"
+    SSE_TEXT = "sse-text"
+    SSE_JSON = "sse-json"
 
 class WorkflowVariableAnnotationConfig(BaseModel):
     name: str = Field(..., description="Name of the annotation.")
@@ -57,29 +60,43 @@ class WorkflowVariableGroupConfig(BaseModel):
     repeat_count: int = Field(default=1, description="The number of times this group of variables should be repeated.")
 
 class WorkflowConfig(BaseModel):
-    name: Optional[str] = Field(default=None)
-    title: Optional[str] = Field(default=None)
-    description: Optional[str] = Field(default=None)
-    jobs: Dict[str, JobConfig] = Field(default_factory=dict)
-    default: bool = Field(default=False)
+    id: str = Field(default="__workflow__", description="ID of workflow.")
+    name: Optional[str] = Field(default=None, description="Name of workflow.")
+    title: Optional[str] = Field(default=None, description="Title of workflow.")
+    description: Optional[str] = Field(default=None, description="Description of workflow.")
+    jobs: List[JobConfig] = Field(default_factory=list, description="List of jobs that define the execution steps.")
+    default: bool = Field(default=False, description="Whether this workflow should be used as the default.")
 
     @model_validator(mode="before")
     def normalize_jobs(cls, values: Dict[str, Any]):
         values = cls.inflate_single_job(values)
         if "jobs" in values:
-           cls.set_default_job_type(values["jobs"])
+           cls.fill_missing_job_type(values["jobs"])
+           cls.fill_missing_delay_job_mode(values["jobs"])
         return values
 
     @classmethod
     def inflate_single_job(cls, values: Dict[str, Any]):
         if "jobs" not in values:
-            job_keys = set(get_model_union_keys(JobConfig))
+            job_keys = set(get_model_union_keys(JobConfig)) - set(WorkflowConfig.model_fields.keys())
             if any(k in values for k in job_keys):
-                values["jobs"] = { "__default__": { k: values.pop(k) for k in job_keys if k in values } }
+                values["jobs"] = [ { k: values.pop(k) for k in job_keys if k in values } ]
         return values
 
     @classmethod
-    def set_default_job_type(cls, jobs: Dict[str, Any]):
-        for job in jobs.values():
+    def fill_missing_job_type(cls, jobs: List[Any]):
+        for job in jobs:
             if "type" not in job:
                 job["type"] = JobType.ACTION
+
+    @classmethod
+    def fill_missing_delay_job_mode(cls, jobs: List[Any]):
+        for job in jobs:
+            if job["type"] == "delay" and "mode" not in job:
+                job["mode"] = DelayJobMode.TIME_INTERVAL
+
+    @field_validator("id")
+    def validate_id(cls, value):
+        if value == "__default__":
+            raise ValueError("Workflow id cannot be '__default__'")
+        return value
